package com.bonus.sgzb.material.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.sgzb.material.domain.PlanBorrowInfo;
import com.bonus.sgzb.material.service.IPlanBorrowInfoService;
import com.bonus.sgzb.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.sgzb.common.log.annotation.Log;
import com.bonus.sgzb.common.log.enums.BusinessType;
import com.bonus.sgzb.common.core.web.controller.BaseController;
import com.bonus.sgzb.common.core.web.domain.AjaxResult;
import com.bonus.sgzb.common.core.web.page.TableDataInfo;

/**
 * 年度借调plan_borrow_infoController
 * 
 * @author bonus
 * @date 2023-12-10
 */
@Api
@RestController
@RequestMapping("/planBorrowInfo")
public class PlanBorrowInfoController extends BaseController
{
    @Autowired
    private IPlanBorrowInfoService planBorrowInfoService;

    /**
     * 查询年度借调plan_borrow_info列表
     */
    @ApiOperation(value = "查询年度借调")
    @GetMapping("/list")
    public TableDataInfo list(PlanBorrowInfo planBorrowInfo)
    {
        startPage();
        List<PlanBorrowInfo> list = planBorrowInfoService.selectPlanBorrowInfoList(planBorrowInfo);
        return getDataTable(list);
    }

    /**
     * 导出年度借调plan_borrow_info列表
     */
    @ApiOperation(value = "导出年度借调")
    @Log(title = "年度借调plan_borrow_info", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PlanBorrowInfo planBorrowInfo)
    {
        List<PlanBorrowInfo> list = planBorrowInfoService.selectPlanBorrowInfoList(planBorrowInfo);
        ExcelUtil<PlanBorrowInfo> util = new ExcelUtil<PlanBorrowInfo>(PlanBorrowInfo.class);
        util.exportExcel(response, list, "年度借调plan_borrow_info数据");
    }

    /**
     * 获取年度借调plan_borrow_info详细信息
     */
    @ApiOperation(value = "获取年度借调")
    @GetMapping(value = "/{borrowId}")
    public AjaxResult getInfo(@PathVariable("borrowId") Long borrowId)
    {
        return success(planBorrowInfoService.selectPlanBorrowInfoByBorrowId(borrowId));
    }

    /**
     * 新增年度借调plan_borrow_info
     */
    @ApiOperation(value = "新增年度借调")
    @Log(title = "年度借调plan_borrow_info", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PlanBorrowInfo planBorrowInfo)
    {
        return toAjax(planBorrowInfoService.insertPlanBorrowInfo(planBorrowInfo));
    }

    /**
     * 修改年度借调plan_borrow_info
     */
    @ApiOperation(value = "修改年度借调")
    @Log(title = "年度借调plan_borrow_info", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PlanBorrowInfo planBorrowInfo)
    {
        return toAjax(planBorrowInfoService.updatePlanBorrowInfo(planBorrowInfo));
    }

    /**
     * 删除年度借调plan_borrow_info
     */
    @ApiOperation(value = "删除年度借调")
    @Log(title = "年度借调plan_borrow_info", businessType = BusinessType.DELETE)
	@DeleteMapping("/{borrowIds}")
    public AjaxResult remove(@PathVariable Long[] borrowIds)
    {
        return toAjax(planBorrowInfoService.deletePlanBorrowInfoByBorrowIds(borrowIds));
    }
}
